# -*- coding: UTF-8 -*-
#
# Copyright 2015-2020 Flavio Garcia
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
The Explanation from the codes are described here: https://bit.ly/2D2ZFY9

Also see:
    http://tldp.org/LDP/abs/html/exitcodes.html
"""

# Catchall for general errors
EX_CATCHALL = 1
# Misuse of shell builtins (according to Bash documentation)
EX_MISUSE = 2
# Command invoked cannot execute
EX_CANNOT_EXECUTE = 126
# Command not found
EX_NOT_FOUND = 127
# Invalid argument to exit
EX_INVALID_ARGUMENT_TO_EXIT = 128
# Fatal error signal "n"
EX_FATAL_ERROR = 128
# Script terminated by Control-C
EX_TERMINATED_BY_CRTL_C = 130
# Exit status out of range
EX_OUT_OF_RANGE = 255

# successful termination
EX_OK = 0
# base value for error messages
EX_BASE = 64
# command line usage error
EX_USAGE = 64
# data format error
EX_DATAERR = 65
# cannot open input
EX_NOINPUT = 66
# addressee unknown
EX_NOUSER = 67
# host name unknown
EX_NOHOST = 68
# service unavailable
EX_UNAVAILABLE = 69
# internal software error
EX_SOFTWARE = 70
# system error (e.g., can't fork)
EX_OSERR = 71
# critical OS file missing
EX_OSFILE = 72
# can't create (user) output file
EX_CANTCREAT = 73
# input/output error
EX_IOERR = 74
# temp failure; user is invited to retry
EX_TEMPFAIL = 75
# remote error in protocol
EX_PROTOCOL = 76
# permission denied
EX_NOPERM = 77
# configuration error
EX_CONFIG = 78

# maximum listed value
EX_MAX = 78


def exit_fatal(signal):
    import sys
    sys.exit(EX_FATAL_ERROR + signal)



# -*- coding: UTF-8 -*-
#
# Copyright 2015-2020 Flavio Garcia
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import string
import sys


# Used implementations described on: http://bit.ly/2gHlH9z
# Recommended here: http://bit.ly/2fm97H3
# Confirmed here:
# https://docs.python.org/2/library/random.html#random.SystemRandom
# TODO: Use that after 3.6 https://bit.ly/2wvubJ6
def random_string(length=5, upper_chars=True, punctuation=False):
    """
    Generate a random string with the size equal to the given length.

    The string is based on random choices from a sequence of ascii lower case
    characters and digits.

    If length is not informed the string size will be 5.
    """
    chars = string.ascii_lowercase + string.digits
    if upper_chars:
        chars += string.ascii_uppercase
    if punctuation:
        chars += string.punctuation
    if sys.version_info < (3, 6):
        import random
        return ''.join(
            random.SystemRandom().choice(chars) for _ in range(length)
        )
    else:
        import secrets
        return ''.join(secrets.choice(chars) for _ in range(length))


class KeyManager(object):

    SALT_SIZE = 24

    def generate(self, password):
        # First is hash second is salt
        # Salt is generated randomly
        return None

    def create_hash(self, password, salt):
        return None

    def validate_password(self, password, correct_hash):
        return False


class Sha512KeyManager(KeyManager):
    # following: https://crackstation.net/hashing-security.htm

    def generate(self, password):
        salt = os.urandom(self.SALT_SIZE).encode('hex')
        return "%s:%s" % (self.create_hash(password, salt), salt)

    def create_hash(self, password, salt):
        import hashlib
        salted_password = "%s%s" % (password, salt)
        return hashlib.sha512(salted_password).hexdigest()

    def validate_password(self, password, correct_hash):
        correct_hashX = correct_hash.split(':')
        canditate_hash = "%s:%s" % (
            self.create_hash(password, correct_hashX[1]), correct_hashX[1])
        return canditate_hash == correct_hash



#!/usr/bin/env python
#
# Copyright 2015-2020 Flavio Garcia
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import cartola
from setuptools import setup
from codecs import open
try:
    # for pip >= 10
    from pip._internal.req import parse_requirements
except ImportError:
    # for pip <= 9.0.3
    from pip.req import parse_requirements

with open("README.md", "r") as fh:
    long_description = fh.read()


# Solution from http://bit.ly/29Yl8VN
def resolve_requires(requirements_file):
    requirements = parse_requirements("./%s" % requirements_file,
            session=False)
    return [str(ir.req) for ir in requirements]


setup(
    name="cartola",
    version=cartola.get_version(),
    license=cartola.__licence__,
    description="Candango's Shared Util Functions.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/candango/cartola",
    author=cartola.get_author(),
    author_email=cartola.get_author_email(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
       #
        "Environment :: Console",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Intended Audience :: System Administrators",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3 :: Only",
        "Topic :: Software Development :: Libraries"
    ],
    packages=["cartola"],
)
